What does KYAK mean? <br>
K --> Kapat in Turkish close or shutdown <br>
Y --> Yeniden Başlat in Turkish reboot   <br>
A --> Askıya al in Turkish Suspend       <br>
K --> Kilitle in Turkish Lock            <br>


<h1>Requirement<h1><br> <br>
First install pip for Python and then <br>

<code>
pip install curses
</code>
